@@ -14,7 +14,7 @@ use Plack::Util;
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.1.4';
+our $VERSION = 'v0.1.5';
 
 
 sub serve_static_file {
@@ -62,7 +62,7 @@ Catalyst::Plugin::Static::File - Serve a specific static file
 
 =head1 VERSION
 
-version v0.1.4
+version v0.1.5
 
 =head1 SYNOPSIS
 
@@ -80,7 +80,7 @@ In a controller method:
 
 This plugin provides a simple method for your L<Catalyst> app to send a specific static file.
 
-Unlike L<Catalyst::Plugin::Static::File>,
+Unlike L<Catalyst::Plugin::Static::Simple>,
 
 =over
 
